@@ -11,9 +11,23 @@
 #include <QStringList>
 #include <QDebug>
 #include <QMaemo5InformationBox>
+#include <QHeaderView>
+#include <QScrollBar>
 #include <qspotify_src/spotifysession.h>
 #include "QueueView.h"
 
+//sorting related defines
+
+//sort columns
+#define COLUMN_TRACK 0
+#define COLUMN_ARTIST 1
+#define COLUMN_ALBUM 2
+
+//sort orders
+#define SORT_ORIGINAL -1
+#define SORT_ASCENDING 0
+#define SORT_DECENDING 1
+
 
 class TrackView : public QMainWindow
 {
@@ -38,12 +52,15 @@ private:
 
     Spotify::Playlist* m_pPlaylist;
 
-    QList<Spotify::Track*> m_TrackList; //list of tracks returned by e.g., search
+    QList<Spotify::Track*> m_TrackList; //list of tracks returned by e.g., search and contained in playlist
 
     QueueView *m_pQueueView;
 
     QTableWidget m_TrackInfo;
 
+    qint32 m_currSortCol; //current sort column
+    qint32 m_currSortOrder; //current sort order
+
     void addTracks(Spotify::Playlist* playlist); //add playlist tracks to main tableview
 
     void addTracks(QList<Spotify::Track*> trackList); //add tracks from specified tracklist to main tableview
@@ -54,6 +71,7 @@ private slots:
 
     void OnTrackActivated(QTableWidgetItem* trackItem);
     void OnPlayQueuePosUpdated(qint32 pos);
+    void OnHeaderClicked(int logicalIndex);
 
 signals:
 
